﻿using System;
using System.Windows;
using Telerik.Windows.Controls.Spreadsheet.Worksheets;
using Telerik.Windows.Documents.Spreadsheet.Model;

namespace DataValidationWorkaround
{
    /// <summary>
    /// Interaction logic for MainWindow.xaml
    /// </summary>
    public partial class MainWindow : Window
    {
        private RadWorksheetEditor worksheetEditor;
        private readonly int MinIntValue = 1;
        private readonly int MaxIntValue = 1000;
        private ICellValue oldCellValue;

        public MainWindow()
        {
            InitializeComponent();

            this.radSpreadsheet.ActiveSheetEditorChanged += this.ActiveSheetEditorChanged;
        }

        private void ActiveSheetEditorChanged(object sender, EventArgs e)
        {
            if (this.worksheetEditor != null)
            {
                this.worksheetEditor.Selection.ActiveCellModeChanged -= this.Selection_ActiveCellModeChanged;
            }

            this.worksheetEditor = this.radSpreadsheet.ActiveWorksheetEditor;

            if (this.worksheetEditor != null)
            {
                this.worksheetEditor.Selection.ActiveCellModeChanged += this.Selection_ActiveCellModeChanged;
            }
        }

        private void Selection_ActiveCellModeChanged(object sender, EventArgs e)
        {
            CellIndex activeCellIndex = this.worksheetEditor.Selection.ActiveCellIndex;
            ICellValue cellValue = this.worksheetEditor.Worksheet.Cells[activeCellIndex].GetValue().Value;

            if (this.worksheetEditor.Selection.ActiveCellMode == ActiveCellMode.Display)
            {
                this.ValidateCellValue(cellValue);
            }
            else
            {
                this.oldCellValue = cellValue;
            }
        }
 
        private void ValidateCellValue(ICellValue cellValue)
        {
            bool isValid = false;

            string stringValue = cellValue.GetResultValueAsString(CellValueFormat.GeneralFormat);

            int intValue;
            if (int.TryParse(stringValue, out intValue))
            {
                if (intValue >= MinIntValue && intValue <= MaxIntValue)
                {
                    isValid = true;
                }
            }

            if (!isValid)
            {
                MessageBox.Show("Not valid!");

                CellIndex activeCellIndex = this.worksheetEditor.Selection.ActiveCellIndex;

                // Be carefull: SetValue() raises the CellPropertyChanged event.
                this.worksheetEditor.Worksheet.Cells[activeCellIndex].SetValue(this.oldCellValue);

                this.worksheetEditor.Focus();
            }
        }
    }
}
